@@ -10,6 +10,7 @@
 #include "searchmodel.h"
 
 #include <DGuiApplicationHelper>
+#include <DIconTheme>
 
 #include <QCoreApplication>
 #include <QDBusConnection>
@@ -21,6 +22,7 @@
 #include <QLoggingCategory>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QQuickWindow>
 #include <QTimer>
 #include <QTranslator>
 #include <QWindow>
@@ -50,6 +52,7 @@ DccManager::DccManager(QObject *parent)
     , m_engine(nullptr)
     , m_navModel(new NavigationModel(this))
     , m_searchModel(new SearchModel(this))
+    , m_showTimer(nullptr)
 {
     m_hideObjects->setName("_hide");
     m_noAddObjects->setName("_noAdd");
@@ -62,21 +65,20 @@ DccManager::DccManager(QObject *parent)
 
     initConfig();
     connect(m_plugins, &PluginManager::addObject, this, &DccManager::addObject, Qt::QueuedConnection);
-    connect(qApp, &QCoreApplication::aboutToQuit, this, &DccManager::onQuit);
-    showPage("system");
+    waitShowPage("system", QDBusMessage());
 }
 
 DccManager::~DccManager()
 {
     qCDebug(dccLog()) << "delete dccManger";
-    onQuit();
+    clearData();
     delete m_plugins;
     qCDebug(dccLog()) << "delete dccManger end";
 }
 
 bool DccManager::installTranslator(const QString &name)
 {
-    QTranslator *translator = new QTranslator();
+    QTranslator *translator = new QTranslator(qApp);
     if (translator->load(QLocale(), name, "_", TRANSLATE_READ_DIR)) {
         qApp->installTranslator(translator);
 #if 1 // 兼容旧版位置
@@ -100,6 +102,9 @@ void DccManager::init()
     auto paths = m_engine->importPathList();
     paths.prepend(DefaultModuleDirectory);
     m_engine->setImportPathList(paths);
+    QStringList dciPaths = Dtk::Gui::DIconTheme::dciThemeSearchPaths();
+    dciPaths << QStringLiteral(DefaultModuleDirectory);
+    Dtk::Gui::DIconTheme::setDciThemeSearchPaths(dciPaths);
 }
 
 QQmlApplicationEngine *DccManager::engine()
@@ -110,6 +115,9 @@ QQmlApplicationEngine *DccManager::engine()
 void DccManager::setMainWindow(QWindow *window)
 {
     m_window = window;
+    connect(m_window, &QWindow::widthChanged, this, &DccManager::saveSize);
+    connect(m_window, &QWindow::heightChanged, this, &DccManager::saveSize);
+    m_window->installEventFilter(this);
 }
 
 void DccManager::loadModules(bool async, const QStringList &dirs)
@@ -122,13 +130,13 @@ void DccManager::loadModules(bool async, const QStringList &dirs)
 int DccManager::width() const
 {
     auto w = m_dconfig->value(WidthConfig).toInt();
-    return w > 780 ? w : 780;
+    return w > 520 ? w : 780;
 }
 
 int DccManager::height() const
 {
     auto h = m_dconfig->value(HeightConfig).toInt();
-    return h > 530 ? h : 530;
+    return h > 400 ? h : 530;
 }
 
 DccApp::UosEdition DccManager::uosEdition() const
@@ -137,6 +145,11 @@ DccApp::UosEdition DccManager::uosEdition() const
     return DccApp::UosEdition(edition);
 }
 
+Q_INVOKABLE Dtk::Core::DSysInfo::ProductType DccManager::productType() const
+{
+    return DSysInfo::productType();
+}
+
 bool DccManager::isTreeland() const
 {
     return Dtk::Gui::DGuiApplicationHelper::testAttribute(Dtk::Gui::DGuiApplicationHelper::IsWaylandPlatform);
@@ -229,11 +242,10 @@ void DccManager::showPage(DccObject *obj, const QString &cmd)
 
 void DccManager::toBack()
 {
-    int row = m_navModel->rowCount();
-    if (row < 3) {
+    int row = m_navModel->rowCount() - 2;
+    if (row < 0) {
         showPage(m_root);
     } else {
-        row = row - 3;
         QString url = m_navModel->data(m_navModel->index(row, 0), NavigationModel::NavUrlRole).toString();
         if (!url.isEmpty()) {
             showPage(url);
@@ -260,7 +272,7 @@ void DccManager::showHelp()
     QDBusConnection::sessionBus().asyncCall(message);
 }
 
-QString DccManager::search(const QString &json)
+QString DccManager::search(const QString &json) const
 {
     QJsonDocument jsonDocument = QJsonDocument::fromJson(json.toLocal8Bit().data());
     if (!jsonDocument.isNull()) {
@@ -301,6 +313,25 @@ QString DccManager::search(const QString &json)
     return QString();
 }
 
+QString DccManager::searchProxy(const QString &json) const
+{
+    if (this->calledFromDBus()) {
+        if (!m_plugins->loadFinished()) {
+            qDebug(dccLog) << "Delay to get searching due to plugins unloaded.";
+            auto message = this->message();
+            setDelayedReply(true);
+            QObject::connect(m_plugins, &PluginManager::loadAllFinished, this, [this, json, message] () {
+                const auto &ret = this->search(json);
+                qDebug(dccLog) << "Searching finished, result size:" << ret.size();
+                QDBusConnection::sessionBus().send(message.createReply(ret));
+            }, Qt::SingleShotConnection);
+
+            return {};
+        }
+    }
+    return search(json);
+}
+
 bool DccManager::stop(const QString &)
 {
     return true;
@@ -426,9 +457,46 @@ DccObject *DccManager::findParent(const DccObject *obj)
     return findObject(path);
 }
 
+bool DccManager::eventFilter(QObject *watched, QEvent *event)
+{
+    if (event->type() == QEvent::MouseButtonPress && watched == m_window && m_window) {
+        QMouseEvent *e = static_cast<QMouseEvent *>(event);
+        if (e->buttons() == Qt::LeftButton) {
+            QQuickWindow *w = static_cast<QQuickWindow *>(m_window);
+            QQuickItem *focusItem = w->activeFocusItem();
+            if (focusItem) {
+                QObject *popup = focusItem->property("popup").value<QObject *>();
+                if (!popup || !popup->property("visible").toBool()) {
+                    QPointF point = focusItem->mapFromGlobal(e->globalPosition());
+                    QRectF rect(0, 0, focusItem->width(), focusItem->height());
+                    if (!rect.contains(point)) {
+                        QQuickItem *item = w->property("sidebarPage").value<QQuickItem *>();
+                        if (item) {
+                            item->forceActiveFocus();
+                        }
+                    }
+                }
+            }
+        }
+    }
+    return DccApp::eventFilter(watched, event);
+}
+
+void DccManager::saveSize()
+{
+    if (m_dconfig->isValid()) {
+        m_dconfig->setValue(WidthConfig, m_window->width());
+        m_dconfig->setValue(HeightConfig, m_window->height());
+    }
+}
+
 void DccManager::waitShowPage(const QString &url, const QDBusMessage message)
 {
     qCInfo(dccLog()) << "show page:" << url;
+    clearShowParam();
+    if (m_plugins->isDeleting()) {
+        return;
+    }
     DccObject *obj = nullptr;
     QString cmd;
     if (url.isEmpty()) {
@@ -442,21 +510,14 @@ void DccManager::waitShowPage(const QString &url, const QDBusMessage message)
         if (obj) {
             showPage(obj, cmd);
         } else if (!m_plugins->loadFinished()) {
-            QEventLoop loop;
-            QTimer timer;
-            connect(&timer, &QTimer::timeout, this, [this, &path, &loop]() {
-                DccObject *obj = findObject(path, true);
-                if (obj) {
-                    loop.quit();
-                }
-            });
-            connect(m_plugins, &PluginManager::loadAllFinished, &loop, &QEventLoop::quit);
-            timer.start(10);
-            loop.exec();
-            obj = findObject(path, true);
-            if (obj) {
-                showPage(obj, cmd);
+            m_showUrl = url;
+            m_showMessage = message;
+            if (!m_showTimer) {
+                m_showTimer = new QTimer(this);
+                connect(m_showTimer, &QTimer::timeout, this, &DccManager::tryShow);
+                m_showTimer->start(10);
             }
+            return;
         }
     }
     if (message.type() != QDBusMessage::InvalidMessage) {
@@ -471,11 +532,52 @@ void DccManager::waitShowPage(const QString &url, const QDBusMessage message)
     }
 }
 
+void DccManager::clearShowParam()
+{
+    if (m_showTimer) {
+        m_showTimer->stop();
+        m_showTimer->deleteLater();
+        m_showTimer = nullptr;
+    }
+    if (!m_showUrl.isEmpty()) {
+        m_showUrl.clear();
+        m_showMessage = QDBusMessage();
+    }
+}
+
+void DccManager::tryShow()
+{
+    if (m_showUrl.isEmpty()) {
+        clearShowParam();
+        return;
+    }
+    int i = m_showUrl.indexOf('?');
+    QString cmd = i != -1 ? m_showUrl.mid(i + 1) : QString();
+    QString path = m_showUrl.mid(0, i).split('/', Qt::SkipEmptyParts).join('/'); // 移除多余的/
+    DccObject *obj = findObject(path, true);
+    if (obj) {
+        showPage(obj, cmd);
+        if (m_showMessage.type() != QDBusMessage::InvalidMessage) {
+            if (cmd.isEmpty()) {
+                show();
+            }
+            QDBusConnection::sessionBus().send(m_showMessage.createReply());
+        }
+        clearShowParam();
+    } else if (m_plugins->loadFinished()) {
+        if (m_showMessage.type() != QDBusMessage::InvalidMessage) {
+            QDBusConnection::sessionBus().send(m_showMessage.createErrorReply(QDBusError::InvalidArgs, QString("not found url:") + m_showUrl));
+        }
+        clearShowParam();
+    }
+}
+
 void DccManager::doShowPage(DccObject *obj, const QString &cmd)
 {
     if (m_plugins->isDeleting() || !obj) {
         return;
     }
+    qCInfo(dccLog) << "ShowPage:" << obj << " have cmd:" << !cmd.isEmpty();
     // 禁用首页
     if (obj == m_root) {
         if (m_root->getChildren().isEmpty()) {
@@ -528,6 +630,7 @@ void DccManager::doShowPage(DccObject *obj, const QString &cmd)
         m_activeObject = m_currentObjects.last();
         Q_EMIT activeObjectChanged(m_activeObject);
     }
+
     m_navModel->setNavigationObject(m_currentObjects);
     qCInfo(dccLog) << "trigger object:" << triggeredObj->name() << " active object:" << m_activeObject->name() << (void *)(triggeredObj->parentItem());
     if (!(triggeredObj->pageType() & DccObject::Menu) && triggeredObj->parentItem()) {
@@ -606,7 +709,9 @@ void DccManager::onVisible(bool visible)
             }
         }
         DccObject::Private::FromObject(m_hideObjects)->removeChild(obj);
-        addObjectToParent(obj);
+        if (!addObjectToParent(obj)) {
+            DccObject::Private::FromObject(m_noAddObjects)->addChild(obj, false);
+        }
     } else {
         removeObjectFromParent(obj);
         DccObject::Private::FromObject(m_hideObjects)->addChild(obj, false);
@@ -687,19 +792,14 @@ bool DccManager::removeObjectFromParent(DccObject *obj)
     return false;
 }
 
-void DccManager::onQuit()
+void DccManager::clearData()
 {
     if (m_plugins->isDeleting()) {
         return;
     }
     m_plugins->beginDelete();
-    int width_remember = m_window->width();
-    int height_remember = m_window->height();
+    clearShowParam();
 
-    if (m_dconfig->isValid()) {
-        m_dconfig->setValue(WidthConfig, width_remember);
-        m_dconfig->setValue(HeightConfig, height_remember);
-    }
     m_window->hide();
     m_window->close();
     // doShowPage(m_root, QString());
@@ -714,9 +814,19 @@ void DccManager::onQuit()
     qCDebug(dccLog()) << "delete root end";
 
     qCDebug(dccLog()) << "delete clearData hide:" << m_hideObjects->getChildren().size() << "noAdd:" << m_noAddObjects->getChildren().size() << "noParent" << m_noParentObjects->getChildren().size();
-    delete m_noAddObjects;
-    delete m_noParentObjects;
-    delete m_hideObjects;
+    QVector<DccObject *> deleteObjects;
+    deleteObjects.append(m_hideObjects);
+    deleteObjects.append(m_noAddObjects);
+    deleteObjects.append(m_noParentObjects);
+    while (!deleteObjects.isEmpty()) {
+        auto obj = deleteObjects.takeFirst();
+        QVector<DccObject *> children = obj->getChildren();
+        while (!children.isEmpty()) {
+            delete children.first();
+            children = obj->getChildren();
+        }
+        delete obj;
+    }
     qCDebug(dccLog()) << "delete dccobject";
     qCDebug(dccLog()) << "delete QmlEngine";
     delete m_engine;
