@@ -47,6 +47,7 @@ public:
     Q_INVOKABLE inline const QVector<DccObject *> &currentObjects() const { return m_currentObjects; }
 
     Q_INVOKABLE DccApp::UosEdition uosEdition() const;
+    Q_INVOKABLE Dtk::Core::DSysInfo::ProductType productType() const;
 
     Q_INVOKABLE bool isTreeland() const;
 
@@ -68,7 +69,8 @@ public Q_SLOTS:
     void show();
     void showHelp();
     // DBus Search
-    QString search(const QString &json);
+    QString search(const QString &json) const;
+    QString searchProxy(const QString &json) const;
     bool stop(const QString &json);
     bool action(const QString &json);
     QString GetAllModule();
@@ -83,9 +85,13 @@ private:
     bool isEqual(const QString &url, const DccObject *obj);
     DccObject *findObject(const QString &url, bool onlyRoot = false);
     DccObject *findParent(const DccObject *obj);
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
 private Q_SLOTS:
+    void saveSize();
     void waitShowPage(const QString &url, const QDBusMessage message);
+    void clearShowParam();
+    void tryShow();
     void doShowPage(DccObject *obj, const QString &cmd);
     void updateModuleConfig(const QString &key);
     void onVisible(bool visible);
@@ -94,7 +100,7 @@ private Q_SLOTS:
     void onObjectDisplayChanged();
     bool addObjectToParent(DccObject *obj);
     bool removeObjectFromParent(DccObject *obj);
-    void onQuit();
+    void clearData();
     void waitLoadFinished() const;
     void doGetAllModule(const QDBusMessage message) const;
 
@@ -115,6 +121,10 @@ private:
     QQmlApplicationEngine *m_engine;
     NavigationModel *m_navModel;
     SearchModel *m_searchModel;
+    // DBus调用时，对应项还没加载完成，此处保存跳转参数
+    QTimer *m_showTimer;
+    QString m_showUrl;
+    QDBusMessage m_showMessage;
 };
 } // namespace dccV25
 #endif // DCCMANAGER_H
