@@ -78,8 +78,8 @@ bool DccObject::Private::setFlagState(uint32_t flag, bool state)
         }
         bool allDisabled = getFlagState(DCC_ALL_DISABLED);
         if (disabled != allDisabled) {
-            if (m_parentItem) {
-                m_parentItem->setEnabled(!allDisabled);
+            if (m_sectionItem) {
+                m_sectionItem->setEnabled(!allDisabled);
             }
             Q_EMIT q_ptr->enabledToAppChanged(disabled);
         }
@@ -134,6 +134,9 @@ void DccObject::Private::removeChild(int index)
     Q_EMIT q_ptr->childAboutToBeRemoved(q_ptr, index);
     m_children.erase(m_children.cbegin() + index);
     DccObject::Private::FromObject(child)->SetParent(nullptr);
+    if (child == m_currentObject) {
+        q_ptr->setCurrentObject(nullptr);
+    }
     Q_EMIT q_ptr->childRemoved(child);
     Q_EMIT q_ptr->childrenChanged(m_children);
 }
@@ -452,7 +455,7 @@ QQuickItem *DccObject::getSectionItem(QObject *parent)
     p_ptr->deleteSectionItem();
     if (p_ptr->m_page) {
         QQmlContext *creationContext = p_ptr->m_page->creationContext();
-        QQmlContext *context = new QQmlContext(creationContext);
+        QQmlContext *context = new QQmlContext(creationContext, p_ptr->m_page);
         context->setContextProperty("dccObj", this);
 #if 0
         QObject *nobj = p_ptr->m_page->beginCreate(context);
@@ -472,6 +475,7 @@ QQuickItem *DccObject::getSectionItem(QObject *parent)
                 } else {
                     p_ptr->m_sectionItem->setParent(this);
                 }
+                p_ptr->m_sectionItem->setEnabled(isEnabledToApp());
             }
             // sections are not controlled by FxListItemSG, so apply attached properties here
         } else {
@@ -483,6 +487,7 @@ QQuickItem *DccObject::getSectionItem(QObject *parent)
         p_ptr->m_sectionItem = qobject_cast<QQuickItem *>(p_ptr->m_page->create(context));
         if (p_ptr->m_sectionItem) {
             p_ptr->m_sectionItem->setParent(this);
+            p_ptr->m_sectionItem->setEnabled(isEnabledToApp());
         } else {
             qCWarning(dccLog()) << "create page error:" << p_ptr->m_page->errorString();
             delete context;
@@ -501,9 +506,6 @@ void DccObject::setParentItem(QQuickItem *item)
 {
     if (item != p_ptr->m_parentItem.get()) {
         p_ptr->m_parentItem = item;
-        if (p_ptr->m_parentItem) {
-            p_ptr->m_parentItem->setEnabled(isEnabledToApp());
-        }
         Q_EMIT parentItemChanged(p_ptr->m_parentItem.get());
     }
 }
