@@ -9,14 +9,20 @@
 #include "accountlistmodel.h"
 
 #include <QFileInfo>
+#include <QPainter>
 #include <QUrl>
 #include <QVariantMap>
 #include <QRegularExpression>
+#include <QPainterPath>
+#include <QBuffer>
 
 #include <DSysInfo>
 
 #include <grp.h>
 
+#define FACEID_NUM    5
+#define Faceimg_SIZE 200
+
 DCORE_USE_NAMESPACE
 namespace dccV25 {
 
@@ -64,6 +70,9 @@ AccountsController::AccountsController(QObject *parent)
         this->groupsUpdate();
     });
     connect(m_worker, &AccountsWorker::updateGroupFailed, this, &AccountsController::groupsUpdateFailed);
+    connect(m_worker, &AccountsWorker::createGroupFailed, this, [this]() {
+        requestClearEmptyGroup(currentUserId());
+    });
     connect(m_worker, &AccountsWorker::updateGroupFinished, this, [this]() {
         updateAllGroups();
         this->groupsUpdate();
@@ -97,7 +106,8 @@ QStringList AccountsController::avatars(const QString &id, const QString &filter
     std::copy_if(list.begin(), list.end(), std::back_inserter(res),
                  [filter, section](const QString &iconFile) {
         bool exists = QFileInfo::exists(QUrl(iconFile).toLocalFile());
-        return exists && iconFile.contains(filter + "/" + section);
+        const QString subPath = section.isEmpty() ? "" : section + "/";
+        return exists && iconFile.contains(filter + "/" + subPath);
     });
 
     std::sort(res.begin(), res.end(), [=](const QString &path1, const QString &path2){
@@ -225,6 +235,16 @@ void AccountsController::setAutoLogin(const QString &id, const bool enable)
             m_worker->setAutoLogin(user, enable);
 }
 
+QString AccountsController::getOtherUserAutoLogin() const
+{
+    for (auto user : m_model->userList()) {
+        if (user->name() != currentUserName() && user->autoLogin()) {
+            return user->name();
+        }
+    }
+    return "";
+}
+
 bool AccountsController::isNoPassWordLoginVisable() const
 {
     return m_model->isNoPassWordLoginVisable();
@@ -537,6 +557,7 @@ QAbstractListModel *AccountsController::accountsModel()
             return;
         auto index = m_accountsModel->index(idIdx);
         m_accountsModel->dataChanged(index, index, {AccountListModel::OnlineRole});
+        emit onlineUserListChanged();
     });
 
     connect(this, &AccountsController::userIdListChanged, static_cast<AccountListModel *>(m_accountsModel), &AccountListModel::reset);
@@ -735,6 +756,15 @@ QString AccountsController::currentUserId() const
     return QString();
 }
 
+bool AccountsController::curUserIsSysAdmin() const
+{
+    User *curUser = m_model->currentUser();
+    if (curUser)
+        return isSystemAdmin(curUser);
+
+    return false;
+}
+
 QStringList AccountsController::userTypes(bool createUser /* = false*/) const
 {
     QStringList types{ tr("Standard User"), tr("Administrator") };
