@@ -22,6 +22,33 @@
 
 static installer::ZoneInfoList g_totalZones;
 
+static QString GetChinaTaiWanName()
+{
+    switch (QLocale::system().territory()) {
+    case QLocale::Territory::China:
+        return QStringLiteral("中国台湾");
+    case QLocale::Territory::HongKong:
+        return QStringLiteral("中國台灣");
+    case QLocale::Territory::Taiwan:
+        return QStringLiteral("中國臺灣");
+    case QLocale::Territory::Macau:
+        return QStringLiteral("中國台灣");
+    default:
+        return "Taiwan China";
+    }
+}
+
+static const QMap<QString, QMap<QLocale::Language, QString>> localeOverrides = {
+    {"zh_TW", {
+        {QLocale::Chinese, GetChinaTaiWanName()},
+        {QLocale::English, "Taiwan China"},
+    }},
+    {"trv_TW", {
+        {QLocale::Chinese, GetChinaTaiWanName()},
+        {QLocale::English, "Taiwan China"}
+    }},
+};
+
 static QString getDescription(const ZoneInfo &zoneInfo)
 {
     const QDateTime localTime(QDateTime::currentDateTime());
@@ -119,6 +146,20 @@ static inline QString escapSpace(const QString &space)
     return isSpace ? QLatin1String(" ") : space;
 }
 
+static inline QString normalizeSpace(const QString &value)
+{
+    QString ret = " ";
+    QStringList numberKeepList{ QString("."), QString(","), QString("'")};
+    if (numberKeepList.contains(value)) {
+        ret = value;
+    } else {
+        if (value == "Space" || value == DatetimeModel::tr("Space")) {
+            return ret;
+        }
+    }
+    return ret;
+}
+
 static inline QString unEscapSpace(const QString &space)
 {
     if (space.isEmpty())
@@ -150,6 +191,13 @@ static QStringList translateLangAndCountry(const QString &localeName)
     std::string displayCountryIcu;
     IcuLocale.getDisplayCountry(systemLocale, localeHex).toUTF8String(displayCountryIcu);
 
+    // override icu， e.g. 台湾 -> 中国台湾
+    if (localeOverrides.contains(localeName)) {
+        if (localeOverrides[localeName].contains(QLocale::system().language())) {
+            displayCountryIcu = localeOverrides[localeName][QLocale::system().language()].toStdString();
+        }
+    }
+
     return QStringList{ QString::fromStdString(displayLanguageIcu),
                         QString::fromStdString(displayCountryIcu) };
 }
@@ -166,12 +214,18 @@ static QString translate(const QString &localeName, const QString &langRegion)
         || langRegions[1] == QLocale::countryToString(QLocale::Macau)
         || langRegions[1] == QLocale::countryToString(QLocale::Taiwan)) {
 
-        QString langCountry =
-                QString("%1(%2)")
-                        .arg(QCoreApplication::translate("dcc::datetime::Language",
-                                                         langRegions.at(0).toUtf8().data()))
-                        .arg(QCoreApplication::translate("dcc::datetime::Country",
-                                                         langRegions.at(1).toUtf8().data()));
+        auto res = translateLangAndCountry(localeName);
+        QString lang = res.value(0);
+
+        // override icu， e.g. 台湾 -> 中国台湾
+        QString country = langRegions.at(1).toUtf8().data();
+        if (country == "Taiwan") {
+            country = GetChinaTaiWanName();
+        } else {
+            country = QCoreApplication::translate("dcc::datetime::Country", langRegions.at(1).toUtf8().data());
+        }
+
+        QString langCountry = QString("%1(%2)").arg(lang).arg(country);
         return langCountry;
     }
 
@@ -404,7 +458,7 @@ QSortFilterProxyModel *DatetimeModel::regionSearchModel()
     }
 
     m_countrySearchModel = new QSortFilterProxyModel(this);
-    QStringListModel *sourceModel = new QStringListModel(m_langRegionsCache.keys());
+    QStringListModel *sourceModel = new QStringListModel(m_langRegionsCache.keys(), m_countrySearchModel);
     m_countrySearchModel->setSourceModel(sourceModel);
     m_countrySearchModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
@@ -439,10 +493,22 @@ QAbstractListModel *DatetimeModel::timeDateModel()
     QStringList names = { tr("Week"), tr("First day of week"), tr("Short date"),
                           tr("Long date"), tr("Short time"), tr("Long time") };
 
-    initModes(names, DayAbbreviations, LongTime, model);
-    connect(this, &DatetimeModel::currentFormatChanged, model, [model, names, this](int format){
-        if (format >= DayAbbreviations && format <= LongTime || format < 0)
-            initModes(names, DayAbbreviations, LongTime, model);
+    auto initFormattedModes = [this, model](const QStringList &names) {
+        QStringList nameList = names;
+        int indexBegin = DayAbbreviations;
+        QStringList langRegions = langRegion().split(":");
+        if (langRegions.size() >= 2 && !langRegions.first().contains("Chinese", Qt::CaseInsensitive)) {
+            indexBegin += 1;
+            nameList.removeFirst();
+        }
+        initModes(nameList, indexBegin, LongTime, model);
+    };
+
+    initFormattedModes(names);
+    connect(this, &DatetimeModel::currentFormatChanged, model, [model, names, this, initFormattedModes](int format){
+        if (format >= DayAbbreviations && format <= LongTime || format < 0) {
+            initFormattedModes(names);
+        }
     });
 
     m_timeDateModel = model;
@@ -517,9 +583,29 @@ void DatetimeModel::setRegion(const QString &region)
 
     m_regionName = region;
     auto reg = m_langRegionsCache.value(region, region);
-    m_work->setConfigValue(country_key, reg);
-    Q_EMIT regionChanged(region);
-    Q_EMIT currentRegionIndexChanged(currentRegionIndex());
+    QLocale locale(QLocale::C);
+    for (const auto &tmplocale : m_regions) {
+        if (tmplocale.territoryToCode(tmplocale.territory()) == reg) {
+            if (m_work->genLocale(tmplocale.name())) {
+                locale = tmplocale;
+                qDebug() << "set locale success:" << locale.name();
+                break;
+            }
+            if (locale.language() == QLocale::C) {
+                locale = tmplocale;
+            }
+        }
+    }
+    if (locale.language() != QLocale::C) {
+        qDebug() << "set locale:" << locale.name();
+        QString country = locale.countryToString(locale.country());
+        QString language = QLocale::languageToString(locale.language());
+        QString langCountry = QString("%1:%2").arg(language).arg(country);
+        m_work->setConfigValue(country_key, country);
+
+        Q_EMIT regionChanged(region);
+        Q_EMIT currentRegionIndexChanged(currentRegionIndex());
+    }
 }
 
 QStringList DatetimeModel::languagesAndRegions()
@@ -573,6 +659,7 @@ void DatetimeModel::setCurrentLocaleAndLangRegion(const QString &localeName, con
     m_work->setDigitGroupingSymbol(unEscapSpace(regionFormat.digitgroupFormat));
     // case PaperSize:
     m_work->setConfigValue(paperFormat_key, regionFormat.paperFormat.toUtf8());
+    m_work->genLocale(locale.name());
 }
 
 QStringList DatetimeModel::availableFormats(int format)
@@ -622,7 +709,7 @@ QStringList DatetimeModel::availableFormats(int format)
         return separatorSymbol(locale, true);
     }
     case DigitGrouping: {
-        QString dgSymbol = escapSpace(m_work->digitGroupingSymbol());
+        QString dgSymbol = escapSpace(normalizeSpace(m_work->digitGroupingSymbol()));
         // 不带数字分隔符，方便自定义追加
         locale.setNumberOptions(QLocale::OmitGroupSeparator);
         // 有的国家使用的是阿拉伯*文*数字（东阿拉伯数字）
@@ -695,12 +782,14 @@ int DatetimeModel::currentFormatIndex(int format)
     case DecimalSymbol: {
         const QString &current = m_work->decimalSymbol();
         QStringList defaultSymbols = separatorSymbol(QLocale(m_localeName), false);
-        return defaultSymbols.indexOf(current);
+        int index = defaultSymbols.indexOf(current);
+        return (index != -1) ? index : defaultSymbols.indexOf(DatetimeModel::tr("Space"));
     }
     case DigitGroupingSymbol: {
         const QString &current = m_work->digitGroupingSymbol();
         QStringList defaultSymbols = separatorSymbol(QLocale(m_localeName), true);
-        return defaultSymbols.indexOf(unEscapSpace(current));
+        int index = defaultSymbols.indexOf(unEscapSpace(current));
+        return (index != -1) ? index : defaultSymbols.indexOf(DatetimeModel::tr("Space"));
     }
     case DigitGrouping: {
         const QString &current = m_work->digitGrouping();
@@ -743,8 +832,9 @@ void DatetimeModel::setCurrentFormat(int format, int index)
     case DayOfWeek: {
         // dconfig
         m_work->setConfigValue(firstDayOfWeek_key, index + 1);
-        // dbus
-        m_work->setWeekStartDayFormat(index + 1);
+        // dbus (from 0 to 6)
+        m_work->setWeekStartDayFormat(index);
+        setFirstDayOfWeek(index + 1);
         break;
     }
     case LongDate: {
@@ -820,7 +910,7 @@ void DatetimeModel::setCurrentFormat(int format, int index)
 
 QString DatetimeModel::currentDate()
 {
-    QLocale locale(m_localeName);
+    QLocale locale(QLocale::system().name());
     QString week = weekdayFormat() == 1 ? "ddd" : "dddd";
     QString dateFormat = shortDateFormat() + " " + week;
 
@@ -829,10 +919,10 @@ QString DatetimeModel::currentDate()
 
 QString DatetimeModel::currentTime() const
 {
-    QLocale locale(m_localeName);
+    QLocale locale(QLocale::system().name());
     QString timeFormat = longTimeFormat();
-    // remove timezone format
-    timeFormat.remove("t");
+    // remove all occurrences of 't' and '[tttt]' or similar patterns
+    timeFormat.remove(QRegularExpression("(\\[t+?\\]|t+)"));
     return locale.toString(QTime::currentTime(), timeFormat);
 }
 
@@ -889,7 +979,7 @@ void DatetimeModel::addUserTimeZone(const ZoneInfo &zone)
 {
     const QString zoneName = zone.getZoneName();
 
-    if (!m_userZoneIds.contains(zoneName)) {
+    if (!m_userZoneIds.contains(zoneName) && zoneName != m_currentSystemTimeZone.getZoneName()) {
         m_userZoneIds.append(zoneName);
         m_userTimeZones.append(zone);
         Q_EMIT userTimeZoneAdded(zone);
