@@ -15,7 +15,6 @@
 
 Q_LOGGING_CATEGORY(DdcDateTimeWorkder, "dcc-datetime-worker")
 
-
 DatetimeWorker::DatetimeWorker(DatetimeModel *model, QObject *parent)
     : QObject(parent)
     , m_model(model)
@@ -37,19 +36,35 @@ DatetimeWorker::DatetimeWorker(DatetimeModel *model, QObject *parent)
             tzinfo = GetZoneInfo(QTimeZone::systemTimeZoneId());
         }
         m_model->setCurrentUseTimeZone(tzinfo);
+        QList<ZoneInfo> zones = m_model->userTimeZones();
+        // Remove the timezone from user list if it becomes the system timezone
+        for (const ZoneInfo &zone : zones) {
+            if (zone.getZoneName() == value) {
+                m_model->removeUserTimeZone(zone);
+                onTimezoneListChanged(m_timedateInter->userTimezones());
+                break;
+            }
+        }
     });
 
     connect(m_timedateInter, &DatetimeDBusProxy::NTPServerChanged, m_model, &DatetimeModel::setNtpServerAddress);
     connect(m_timedateInter, &DatetimeDBusProxy::TimezoneChanged, m_model, &DatetimeModel::setTimeZoneInfo);
     connect(m_timedateInter, &DatetimeDBusProxy::WeekdayFormatChanged, m_model, &DatetimeModel::weekdayFormatChanged);
 
-    connect(m_timedateInter, &DatetimeDBusProxy::CurrencySymbolChanged, m_model, [this](const QString &symbol){
+    connect(m_timedateInter, &DatetimeDBusProxy::CurrencySymbolChanged, m_model, [this](const QString &symbol) {
+        Q_EMIT m_model->symbolChanged(DatetimeModel::CurrencySymbol, symbol);
+    });
+    connect(m_timedateInter, &DatetimeDBusProxy::NegativeCurrencyFormatChanged, m_model, [this](const QString &symbol) {
+        Q_EMIT m_model->symbolChanged(DatetimeModel::CurrencySymbol, symbol);
+    });
+    connect(m_timedateInter, &DatetimeDBusProxy::PositiveCurrencyFormatChanged, m_model, [this](const QString &symbol) {
         Q_EMIT m_model->symbolChanged(DatetimeModel::CurrencySymbol, symbol);
     });
     connect(m_timedateInter, &DatetimeDBusProxy::DecimalSymbolChanged, m_model, [this](const QString &symbol){
         Q_EMIT m_model->symbolChanged(DatetimeModel::DecimalSymbol, symbol);
     });
     connect(m_timedateInter, &DatetimeDBusProxy::DigitGroupingSymbolChanged, m_model, [this](const QString &symbol){
+        m_model->setDigitGroupingSymbol(symbol);
         Q_EMIT m_model->symbolChanged(DatetimeModel::DigitGroupingSymbol, symbol);
     });
 
@@ -61,6 +76,7 @@ DatetimeWorker::DatetimeWorker(DatetimeModel *model, QObject *parent)
     m_model->setNtpServerAddress(m_timedateInter->nTPServer());
     m_model->setTimeZoneInfo(m_timedateInter->timezone());
     m_model->setNTP(m_timedateInter->nTP());
+    m_model->setDigitGroupingSymbol(m_timedateInter->digitGroupingSymbol());
 
     initRegionFormatData();
 }
@@ -136,9 +152,9 @@ void DatetimeWorker::setTimezone(const QString &timezone)
     m_timedateInter->SetTimezone(timezone);
 }
 
-void DatetimeWorker::removeUserTimeZone(const ZoneInfo &info)
+void DatetimeWorker::removeUserTimeZone(const QString &zone)
 {
-    m_timedateInter->DeleteUserTimezone(info.getZoneName());
+    m_timedateInter->DeleteUserTimezone(zone);
 }
 
 void DatetimeWorker::addUserTimeZone(const QString &zone)
@@ -150,7 +166,7 @@ void DatetimeWorker::setNtpServer(QString server)
 {
     qInfo() << "Try set server : " << server;
 
-    if (server.isEmpty() || server == m_timedateInter->nTPServer())
+    if (server == m_timedateInter->nTPServer())
         return;
     m_timedateInter->SetNTPServer(server, tr("Authentication is required to change NTP server"), this, SLOT(SetNTPServerFinished()), SLOT(SetNTPServerError()));
 }
@@ -306,58 +322,78 @@ void DatetimeWorker::initRegionFormatData()
         return;
 
     if (m_config->isDefaultValue(country_key)) {
+        setConfigValue(country_key, m_regionInter->systemCountry());
         m_model->setCountry(m_regionInter->systemCountry());
     } else {
         m_model->setCountry(m_config->value(country_key).toString());
     }
     if (m_config->isDefaultValue(languageRegion_key) || m_config->value(languageRegion_key).toString().isEmpty()) {
+        setConfigValue(languageRegion_key, m_regionInter->langCountry());
         m_model->setLangRegion(m_regionInter->langCountry());
     } else {
         m_model->setLangRegion(m_config->value(languageRegion_key).toString());
     }
     if (m_config->isDefaultValue(localeName_key)) {
+        setConfigValue(localeName_key, QLocale::system().name());
         m_model->setLocaleName(QLocale::system().name());
     } else {
         m_model->setLocaleName(m_config->value(localeName_key).toString());
     }
     if (m_config->isDefaultValue(firstDayOfWeek_key)) {
         QLocale locale(QLocale::system().name());
+        setConfigValue(firstDayOfWeek_key, m_regionInter->regionFormat(locale).firstDayOfWeekFormat);
         m_model->setFirstDayOfWeek(m_regionInter->regionFormat(locale).firstDayOfWeekFormat);
     } else {
         m_model->setFirstDayOfWeek(m_config->value(firstDayOfWeek_key).toInt());
     }
     if (m_config->isDefaultValue(shortDateFormat_key)) {
         QLocale locale(QLocale::system().name());
+        setConfigValue(shortDateFormat_key, m_regionInter->regionFormat(locale).shortDateFormat);
         m_model->setShortDateFormat(m_regionInter->regionFormat(locale).shortDateFormat);
     } else {
         m_model->setShortDateFormat(m_config->value(shortDateFormat_key).toString());
     }
     if (m_config->isDefaultValue(longDateFormat_key)) {
         QLocale locale(QLocale::system().name());
+        setConfigValue(longDateFormat_key, m_regionInter->regionFormat(locale).longDateFormat);
         m_model->setLongDateFormat(m_regionInter->regionFormat(locale).longDateFormat);
     } else {
         m_model->setLongDateFormat(m_config->value(longDateFormat_key).toString());
     }
     if (m_config->isDefaultValue(shortTimeFormat_key)) {
         QLocale locale(QLocale::system().name());
+        setConfigValue(shortTimeFormat_key, m_regionInter->regionFormat(locale).shortTimeFormat);
         m_model->setShortTimeFormat(m_regionInter->regionFormat(locale).shortTimeFormat);
     } else {
         m_model->setShortTimeFormat(m_config->value(shortTimeFormat_key).toString());
     }
     if (m_config->isDefaultValue(longTimeFormat_key)) {
         QLocale locale(QLocale::system().name());
+        setConfigValue(longTimeFormat_key, m_regionInter->regionFormat(locale).longTimeFormat);
         m_model->setLongTimeFormat(m_regionInter->regionFormat(locale).longTimeFormat);
     } else {
         m_model->setLongTimeFormat(m_config->value(longTimeFormat_key).toString());
     }
     if (m_config->isDefaultValue(currencyFormat_key)) {
         QLocale locale(QLocale::system().name());
-        m_model->setCurrencyFormat(m_regionInter->regionFormat(locale).currencyFormat);
+        const auto newFormat = m_regionInter->regionFormat(locale).currencyFormat;
+        setConfigValue(currencyFormat_key, newFormat);
+        m_model->setCurrencyFormat(newFormat);
+
+        const auto oldFormat = currencySymbol();
+        auto posFmt = positiveCurrencyFormat();
+        posFmt.replace(oldFormat, newFormat);
+        auto negFmt = negativeCurrencyFormat();
+        negFmt.replace(oldFormat, newFormat);
+        QMetaObject::invokeMethod(this, "setCurrencySymbol", Qt::QueuedConnection, newFormat);
+        QMetaObject::invokeMethod(this, "setPositiveCurrencyFormat", Qt::QueuedConnection, posFmt);
+        QMetaObject::invokeMethod(this, "setNegativeCurrencyFormat", Qt::QueuedConnection, negFmt);
     } else {
         m_model->setCurrencyFormat(m_config->value(currencyFormat_key).toString());
     }
     if (m_config->isDefaultValue(numberFormat_key)) {
         QLocale locale(QLocale::system().name());
+        setConfigValue(numberFormat_key, m_regionInter->regionFormat(locale).numberFormat);
         m_model->setNumberFormat(m_regionInter->regionFormat(locale).numberFormat);
     } else {
         m_model->setNumberFormat(m_config->value(numberFormat_key).toString());
@@ -365,6 +401,7 @@ void DatetimeWorker::initRegionFormatData()
     if (m_config->isDefaultValue(paperFormat_key)) {
         QLocale locale(QLocale::system().name());
         m_model->setPaperFormat(m_regionInter->regionFormat(locale).paperFormat);
+        setConfigValue(paperFormat_key, m_regionInter->regionFormat(locale).paperFormat);
     } else {
         m_model->setPaperFormat(m_config->value(paperFormat_key).toString());
     }
@@ -447,7 +484,7 @@ void DatetimeWorker::setConfigValue(const QString &key, const QVariant &value)
     m_config->setValue(key, value);
 }
 
-void DatetimeWorker::genLocale(const QString &localeName)
+bool DatetimeWorker::genLocale(const QString &localeName)
 {
     static QString localeConfPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QDir::separator() + "locale.conf";
 
@@ -455,7 +492,7 @@ void DatetimeWorker::genLocale(const QString &localeName)
 
     auto supportedLocaleListRes = getSupportedLocale();
     if (!supportedLocaleListRes.has_value()) {
-        return;
+        return false;
     }
 
     QStringList supportedLocaleList = supportedLocaleListRes.value();
@@ -466,9 +503,8 @@ void DatetimeWorker::genLocale(const QString &localeName)
     } else if (supportedLocaleList.contains(localeName)) {
         localeSet = localeName;
     } else {
-        return;
+        return false;
     }
-
     settings.setValue("LC_NUMERIC", localeSet);
     settings.setValue("LC_MONETARY", localeSet);
     settings.setValue("LC_TIME", localeSet);
@@ -477,4 +513,5 @@ void DatetimeWorker::genLocale(const QString &localeName)
     settings.setValue("LC_ADDRESS", localeSet);
     settings.setValue("LC_TELEPHONE", localeSet);
     settings.setValue("LC_MEASUREMENT", localeSet);
+    return true;
 }
