@@ -50,6 +50,8 @@ DisplayWorker::DisplayWorker(DisplayModel *model, QObject *parent, bool isSync)
             onWlMonitorListChanged();
         });
     } else {
+        connect(m_displayInter, &DisplayDBusProxy::WallpaperURlsChanged, this, &DisplayWorker::updateWallpaper);
+        connect(m_displayInter, &DisplayDBusProxy::WorkspaceSwitched, this, &DisplayWorker::updateWallpaper);
         connect(m_displayInter, &DisplayDBusProxy::MonitorsChanged, this, &DisplayWorker::onMonitorListChanged);
         connect(m_displayInter, &DisplayDBusProxy::BrightnessChanged, this, &DisplayWorker::onMonitorsBrightnessChanged);
         connect(m_displayInter, &DisplayDBusProxy::BrightnessChanged, model, &DisplayModel::setBrightnessMap);
@@ -59,13 +61,15 @@ DisplayWorker::DisplayWorker(DisplayModel *model, QObject *parent, bool isSync)
         connect(m_displayInter, &DisplayDBusProxy::ScreenWidthChanged, model, &DisplayModel::setScreenWidth);
         connect(m_displayInter, &DisplayDBusProxy::DisplayModeChanged, model, &DisplayModel::setDisplayMode);
         connect(m_displayInter, &DisplayDBusProxy::MaxBacklightBrightnessChanged, model, &DisplayModel::setmaxBacklightBrightness);
+        connect(m_displayInter, &DisplayDBusProxy::ColorTemperatureEnabledChanged, model, &DisplayModel::setColorTemperatureEnabled);
         connect(m_displayInter, &DisplayDBusProxy::ColorTemperatureModeChanged, model, &DisplayModel::setAdjustCCTmode);
         connect(m_displayInter, &DisplayDBusProxy::ColorTemperatureManualChanged, model, &DisplayModel::setColorTemperature);
+        connect(m_displayInter, &DisplayDBusProxy::CustomColorTempTimePeriodChanged, model, &DisplayModel::setCustomColorTempTimePeriod);
         connect(m_displayInter, static_cast<void (DisplayDBusProxy::*)(const QString &) const>(&DisplayDBusProxy::PrimaryChanged), model, &DisplayModel::setPrimary);
 
         //display redSfit/autoLight
         connect(m_displayInter, &DisplayDBusProxy::HasAmbientLightSensorChanged, m_model, &DisplayModel::autoLightAdjustVaildChanged);
-        connect(m_timer, &QTimer::timeout, this, [=] {
+        connect(m_timer, &QTimer::timeout, this, [this] {
             m_displayInter->ApplyChanges().waitForFinished();
             m_displayInter->Save().waitForFinished();
         });
@@ -117,7 +121,9 @@ void DisplayWorker::active()
         m_model->setScreenHeight(m_displayInter->screenHeight());
         m_model->setScreenWidth(m_displayInter->screenWidth());
         m_model->setAdjustCCTmode(m_displayInter->colorTemperatureMode());
+        m_model->setColorTemperatureEnabled(m_displayInter->colorTemperatureEnabled());
         m_model->setColorTemperature(m_displayInter->colorTemperatureManual());
+        m_model->setCustomColorTempTimePeriod(m_displayInter->customColorTempTimePeriod());
         m_model->setmaxBacklightBrightness(m_displayInter->maxBacklightBrightness());
         m_model->setAutoLightAdjustIsValid(m_displayInter->hasAmbientLightSensor());
 
@@ -230,6 +236,18 @@ void DisplayWorker::onWlMonitorListChanged()
     }
 }
 
+void DisplayWorker::updateWallpaper()
+{
+    for (auto it(m_monitors.cbegin()); it != m_monitors.cend(); ++it) {
+        updateMonitorWallpaper(it.key());
+    }
+}
+
+void DisplayWorker::updateMonitorWallpaper(Monitor *mon)
+{
+    mon->setWallpaper(m_displayInter->GetCurrentWorkspaceBackgroundForMonitor(mon->name()));
+}
+
 void DisplayWorker::onMonitorsBrightnessChanged(const BrightnessMap &brightness)
 {
     if (brightness.isEmpty())
@@ -301,6 +319,7 @@ constexpr static int dccRotate2wl(int dccRotate) {
 
 void DisplayWorker::setMonitorRotate(Monitor *mon, const quint16 rotate)
 {
+    m_model->setmodeChanging(true);
     if (WQt::Utils::isTreeland()) {
         auto *opCfg = m_reg->outputManager()->createConfiguration();
         for (auto it(m_wl_monitors.cbegin()); it != m_wl_monitors.cend(); ++it) {
@@ -378,6 +397,11 @@ void DisplayWorker::applyChanges()
     }
 }
 
+void DisplayWorker::setColorTemperatureEnabled(bool enabled)
+{
+    m_displayInter->setColorTemperatureEnabled(enabled);
+}
+
 void DisplayWorker::setColorTemperature(int value)
 {
     if (WQt::Utils::isTreeland()) {
@@ -397,6 +421,11 @@ void DisplayWorker::SetMethodAdjustCCT(int mode)
     m_displayInter->SetMethodAdjustCCT(mode);
 }
 
+void DisplayWorker::setCustomColorTempTimePeriod(const QString &timePeriod)
+{
+    m_displayInter->SetCustomColorTempTimePeriod(timePeriod);
+}
+
 void DisplayWorker::setCurrentFillMode(Monitor *mon,const QString fillMode)
 {
     if (WQt::Utils::isTreeland()) {
@@ -442,6 +471,7 @@ void DisplayWorker::resetBackup()
 
 void DisplayWorker::setMonitorResolution(Monitor *mon, const int mode)
 {
+    m_model->setmodeChanging(true);
     if (WQt::Utils::isTreeland()) {
         auto *opCfg = m_reg->outputManager()->createConfiguration();
         auto res = mon->getResolutionById(mode);
@@ -677,7 +707,7 @@ void DisplayWorker::monitorAdded(const QString &path)
     if (!m_model->brightnessMap().isEmpty()) {
         mon->setBrightness(m_model->brightnessMap()[mon->name()]);
     }
-
+    updateMonitorWallpaper(mon);
     m_model->monitorAdded(mon);
     m_monitors.insert(mon, inter);
 }
@@ -883,6 +913,7 @@ void DisplayWorker::setTouchScreenAssociation(const QString &monitor, const QStr
 
 void DisplayWorker::setMonitorResolutionBySize(Monitor *mon, const int width, const int height)
 {
+    m_model->setmodeChanging(true);
     if (WQt::Utils::isTreeland()) {
         auto *opCfg = m_reg->outputManager()->createConfiguration();
         for (auto it(m_wl_monitors.cbegin()); it != m_wl_monitors.cend(); ++it) {
