@@ -38,7 +38,9 @@ QStringList systemFilter = {"terminal",
                             "wm-switcher",
                             "system-monitor",
                             "color-picker",
-                            "clipboard"};
+                            "clipboard",
+                            "switch-monitors"
+};
 
 const QStringList &windowFilter = {"maximize",
                                    "unmaximize",
@@ -58,7 +60,10 @@ const QStringList &workspaceFilter = {"switch-to-workspace-left",
 const QStringList &assistiveToolsFilter = {"ai-assistant",
                                            "text-to-speech",
                                            "speech-to-text",
-                                           "translation"};
+                                           "translation",
+                                            "view-zoom-in",
+                                            "view-zoom-out",
+                                            "view-actual-size"};
 
 // from dquickrectangle_p.h
 #define NoneCorner 0x0
@@ -94,9 +99,6 @@ ShortcutModel::ShortcutModel(QObject *parent)
     : QObject(parent)
     , m_windowSwitchState(false)
 {
-    if (qApp->screens().count() > 1) {
-        systemFilter.append("switch-monitors");
-    }
 }
 
 ShortcutModel::~ShortcutModel()
