@@ -3,6 +3,7 @@
 //SPDX-License-Identifier: GPL-3.0-or-later
 #include "personalizationdbusproxy.h"
 
+#include <DGuiApplicationHelper>
 #include <QMetaObject>
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -12,10 +13,6 @@ const QString AppearanceService = QStringLiteral("org.deepin.dde.Appearance1");
 const QString AppearancePath = QStringLiteral("/org/deepin/dde/Appearance1");
 const QString AppearanceInterface = QStringLiteral("org.deepin.dde.Appearance1");
 
-const QString WMSwitcherService = QStringLiteral("org.deepin.dde.WMSwitcher1");
-const QString WMSwitcherPath = QStringLiteral("/org/deepin/dde/WMSwitcher1");
-const QString WMSwitcherInterface = QStringLiteral("org.deepin.dde.WMSwitcher1");
-
 const QString WMService = QStringLiteral("com.deepin.wm");
 const QString WMPath = QStringLiteral("/com/deepin/wm");
 const QString WMInterface = QStringLiteral("com.deepin.wm");
@@ -24,24 +21,44 @@ const QString EffectsService = QStringLiteral("org.kde.KWin");
 const QString EffectsPath = QStringLiteral("/Effects");
 const QString EffectsInterface = QStringLiteral("org.kde.kwin.Effects");
 
+const QString DaemonService = QStringLiteral("org.deepin.dde.Daemon1");
+const QString DaemonPath = QStringLiteral("/org/deepin/dde/Daemon1");
+const QString DaemonInterface = QStringLiteral("org.deepin.dde.Daemon1");
+
+const QString ScreenSaverServive = QStringLiteral("com.deepin.ScreenSaver");
+const QString ScreenSaverPath = QStringLiteral("/com/deepin/ScreenSaver");
+const QString ScreenSaverInterface = QStringLiteral("com.deepin.ScreenSaver");
+
+const QString WallpaperSlideshowService = QStringLiteral("org.deepin.dde.WallpaperSlideshow");
+const QString WallpaperSlideshowPath = QStringLiteral("/org/deepin/dde/WallpaperSlideshow");
+const QString WallpaperSlideshowInterface = QStringLiteral("org.deepin.dde.WallpaperSlideshow");
+
 const QString PropertiesInterface = QStringLiteral("org.freedesktop.DBus.Properties");
 const QString PropertiesChanged = QStringLiteral("PropertiesChanged");
 
+DGUI_USE_NAMESPACE
+
 PersonalizationDBusProxy::PersonalizationDBusProxy(QObject *parent)
     : QObject(parent)
-    , m_AppearanceInter(new QDBusInterface(AppearanceService, AppearancePath, AppearanceInterface, QDBusConnection::sessionBus(), this))
-    , m_WMSwitcherInter(new QDBusInterface(WMSwitcherService, WMSwitcherPath, WMSwitcherInterface, QDBusConnection::sessionBus(), this))
-    , m_WMInter(new QDBusInterface(WMService, WMPath, WMInterface, QDBusConnection::sessionBus(), this))
-    , m_EffectsInter(new QDBusInterface(EffectsService, EffectsPath, EffectsInterface, QDBusConnection::sessionBus(), this))
-
 {
+    m_AppearanceInter = new QDBusInterface(AppearanceService, AppearancePath, AppearanceInterface, QDBusConnection::sessionBus(), this);
+    m_DaemonInter = new QDBusInterface(DaemonService, DaemonPath, DaemonInterface, QDBusConnection::systemBus(), this);
+    m_screenSaverInter = new QDBusInterface(ScreenSaverServive, ScreenSaverPath, ScreenSaverInterface, QDBusConnection::sessionBus(), this);
+    m_wallpaperSlideshowInter = new QDBusInterface(WallpaperSlideshowService, WallpaperSlideshowPath, WallpaperSlideshowInterface, QDBusConnection::sessionBus(), this);
+    if (!DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::IsWaylandPlatform)) {
+        m_WMInter = new QDBusInterface(WMService, WMPath, WMInterface, QDBusConnection::sessionBus(), this);
+        m_EffectsInter = new QDBusInterface(EffectsService, EffectsPath, EffectsInterface, QDBusConnection::sessionBus(), this);
+
+        QDBusConnection::sessionBus().connect(WMService, WMPath, PropertiesInterface, PropertiesChanged, this, SLOT(onPropertiesChanged(QDBusMessage)));
+    }
+    
     QDBusConnection::sessionBus().connect(AppearanceService, AppearancePath, PropertiesInterface, PropertiesChanged, this, SLOT(onPropertiesChanged(QDBusMessage)));
-    QDBusConnection::sessionBus().connect(WMService, WMPath, PropertiesInterface, PropertiesChanged, this, SLOT(onPropertiesChanged(QDBusMessage)));
+    QDBusConnection::sessionBus().connect(ScreenSaverServive, ScreenSaverPath, PropertiesInterface, PropertiesChanged, this, SLOT(onPropertiesChanged(QDBusMessage)));
+    QDBusConnection::sessionBus().connect(WallpaperSlideshowService, WallpaperSlideshowPath, PropertiesInterface, PropertiesChanged, this, SLOT(onPropertiesChanged(QDBusMessage)));
 
     connect(m_AppearanceInter, SIGNAL(Changed(const QString &, const QString &)), this, SIGNAL(Changed(const QString &, const QString &)));
     connect(m_AppearanceInter, SIGNAL(Refreshed(const QString &)), this, SIGNAL(Refreshed(const QString &)));
-    connect(m_WMSwitcherInter, SIGNAL(WMChanged(const QString &)), this, SIGNAL(WMChanged(const QString &)));
-    connect(m_WMInter, SIGNAL(compositingEnabledChanged(bool)), this, SIGNAL(compositingEnabledChanged(bool)));
+    connect(m_DaemonInter, SIGNAL(WallpaperChanged(const QString &, uint, const QStringList &)), this, SIGNAL(WallpaperChanged(const QString &, uint, const QStringList &)));
 }
 
 // Appearance
@@ -145,12 +162,22 @@ void PersonalizationDBusProxy::setStandardFont(const QString &value)
 
 QString PersonalizationDBusProxy::wallpaperSlideShow()
 {
-    return qvariant_cast<QString>(m_AppearanceInter->property("WallpaperSlideShow"));
+    return qvariant_cast<QString>(m_wallpaperSlideshowInter->property("WallpaperSlideShow"));
 }
 
-void PersonalizationDBusProxy::setWallpaperSlideShow(const QString &value)
+QString PersonalizationDBusProxy::wallpaperSlideShow(const QString &monitorName)
 {
-    m_AppearanceInter->setProperty("WallpaperSlideShow", QVariant::fromValue(value));
+    return QDBusPendingReply<QString>(m_wallpaperSlideshowInter->asyncCall(QStringLiteral("GetWallpaperSlideShow"), QVariant::fromValue(monitorName)));
+}
+
+void PersonalizationDBusProxy::setWallpaperSlideShow(const QString &monitorName, const QString &slideShow)
+{
+    m_wallpaperSlideshowInter->asyncCall("SetWallpaperSlideShow", QVariant::fromValue(monitorName), QVariant::fromValue(slideShow));
+}
+
+void PersonalizationDBusProxy::setWallpaperSlideShow(const QString &wallpaperSlideShow)
+{
+    m_wallpaperSlideshowInter->setProperty("WallpaperSlideShow", QVariant::fromValue(wallpaperSlideShow));
 }
 
 int PersonalizationDBusProxy::windowRadius()
@@ -230,97 +257,213 @@ void PersonalizationDBusProxy::SetCurrentWorkspaceBackgroundForMonitor(const QSt
     m_AppearanceInter->asyncCall(QStringLiteral("SetCurrentWorkspaceBackgroundForMonitor"), url, screenName);
 }
 
+void PersonalizationDBusProxy::SetGreeterBackground(const QString &url)
+{
+    m_AppearanceInter->asyncCall(QStringLiteral("Set"), QStringLiteral("greeterbackground"), QVariant::fromValue(url));
+}
+
 QString PersonalizationDBusProxy::getCurrentWorkSpaceBackgroundForMonitor(const QString &screenName)
 {
     return QDBusPendingReply<QString>(m_AppearanceInter->asyncCall(QStringLiteral("GetCurrentWorkspaceBackgroundForMonitor"), screenName));
 }
 
-// WMSwitcher
-bool PersonalizationDBusProxy::AllowSwitch()
+// Daemon
+void PersonalizationDBusProxy::deleteCustomWallpaper(const QString &userName, const QString &url)
 {
-    return QDBusPendingReply<bool>(m_WMSwitcherInter->asyncCall(QStringLiteral("AllowSwitch")));
+    m_DaemonInter->asyncCall(QStringLiteral("DeleteCustomWallPaper"), QVariant::fromValue(userName), QVariant::fromValue(url));
 }
 
-QString PersonalizationDBusProxy::CurrentWM()
+QString PersonalizationDBusProxy::saveCustomWallpaper(const QString &userName, const QString &url)
 {
-    return QDBusPendingReply<QString>(m_WMSwitcherInter->asyncCall(QStringLiteral("CurrentWM")));
+    return QDBusPendingReply<QString>(m_DaemonInter->asyncCall(QStringLiteral("SaveCustomWallPaper"), QVariant::fromValue(userName), QVariant::fromValue(url)));
 }
 
-bool PersonalizationDBusProxy::CurrentWM(QObject *receiver, const char *member)
+QStringList PersonalizationDBusProxy::getCustomWallpaper(const QString &userName)
 {
-    QList<QVariant> args;
-    return m_WMSwitcherInter->callWithCallback(QStringLiteral("CurrentWM"), args, receiver, member);
+    return QDBusPendingReply<QStringList>(m_DaemonInter->asyncCall(QStringLiteral("GetCustomWallPapers"), QVariant::fromValue(userName)));
 }
 
-void PersonalizationDBusProxy::RequestSwitchWM()
+// screenSaver
+QStringList PersonalizationDBusProxy::getAllscreensaver()
 {
-    m_WMSwitcherInter->asyncCall(QStringLiteral("RequestSwitchWM"));
+    return qvariant_cast<QStringList>(m_screenSaverInter->property("allScreenSaver"));
+}
+
+QString PersonalizationDBusProxy::GetScreenSaverCover(const QString &name)
+{
+    return QDBusPendingReply<QString>(m_screenSaverInter->asyncCall(QStringLiteral("GetScreenSaverCover"), QVariant::fromValue(name)));
+}
+
+QStringList PersonalizationDBusProxy::ConfigurableItems()
+{
+    return QDBusPendingReply<QStringList>(m_screenSaverInter->asyncCall(QStringLiteral("ConfigurableItems")));
+}
+
+void PersonalizationDBusProxy::setCurrentScreenSaver(const QString &value)
+{
+    m_screenSaverInter->setProperty("currentScreenSaver", QVariant::fromValue(value));
+}
+
+QString PersonalizationDBusProxy::getCurrentScreenSaver()
+{
+    return qvariant_cast<QString>(m_screenSaverInter->property("currentScreenSaver"));
+}
+
+void PersonalizationDBusProxy::startScreenSaver()
+{
+    m_screenSaverInter->asyncCall(QStringLiteral("Start"));
+}
+
+void PersonalizationDBusProxy::stopScreenSaver()
+{
+    m_screenSaverInter->asyncCall(QStringLiteral("Stop"));
+}
+
+void PersonalizationDBusProxy::setLinePowerScreenSaverTimeout(int value)
+{
+    m_screenSaverInter->setProperty("linePowerScreenSaverTimeout", QVariant::fromValue(value));
+}
+
+void PersonalizationDBusProxy::setBatteryScreenSaverTimeout(int value)
+{
+    m_screenSaverInter->setProperty("batteryScreenSaverTimeout", QVariant::fromValue(value));
+}
+
+int PersonalizationDBusProxy::getLinePowerScreenSaverTimeout()
+{
+    return qvariant_cast<int>(m_screenSaverInter->property("linePowerScreenSaverTimeout"));
+}
+
+int PersonalizationDBusProxy::getBatteryScreenSaverTimeout()
+{
+    return qvariant_cast<int>(m_screenSaverInter->property("batteryScreenSaverTimeout"));
+}
+
+void PersonalizationDBusProxy::requestScreenSaverConfig(const QString& name)
+{
+    m_screenSaverInter->asyncCall(QStringLiteral("StartCustomConfig"), QVariant::fromValue(name));
+}
+
+bool PersonalizationDBusProxy::getLockScreenAtAwake()
+{
+    return qvariant_cast<bool>(m_screenSaverInter->property("lockScreenAtAwake"));
+}
+
+void PersonalizationDBusProxy::setLockScreenAtAwake(bool value)
+{
+    m_screenSaverInter->setProperty("lockScreenAtAwake", QVariant::fromValue(value));
 }
 
 // WM
 bool PersonalizationDBusProxy::compositingAllowSwitch()
 {
+    if (!m_WMInter) {
+        return false;
+    }
     return qvariant_cast<bool>(m_WMInter->property("compositingAllowSwitch"));
 }
 
 bool PersonalizationDBusProxy::compositingEnabled()
 {
+    if (!m_WMInter) {
+        return false;
+    }
     return qvariant_cast<bool>(m_WMInter->property("compositingEnabled"));
 }
 
 void PersonalizationDBusProxy::setCompositingEnabled(bool value)
 {
+    if (!m_WMInter) {
+        return;
+    }
     m_WMInter->setProperty("compositingEnabled", QVariant::fromValue(value));
 }
 
 bool PersonalizationDBusProxy::compositingPossible()
 {
+    if (!m_WMInter) {
+        return false;
+    }
     return qvariant_cast<bool>(m_WMInter->property("compositingPossible"));
 }
 
 int PersonalizationDBusProxy::cursorSize()
 {
+    if (!m_WMInter) {
+        return 0;
+    }
     return qvariant_cast<int>(m_WMInter->property("cursorSize"));
 }
 
 void PersonalizationDBusProxy::setCursorSize(int value)
 {
+    if (!m_WMInter) {
+        return;
+    }
     m_WMInter->setProperty("cursorSize", QVariant::fromValue(value));
 }
 
 bool PersonalizationDBusProxy::zoneEnabled()
 {
+    if (!m_WMInter) {
+        return false;
+    }
     return qvariant_cast<bool>(m_WMInter->property("zoneEnabled"));
 }
 
 void PersonalizationDBusProxy::setZoneEnabled(bool value)
 {
+    if (!m_WMInter) {
+        return;
+    }
     m_WMInter->setProperty("zoneEnabled", QVariant::fromValue(value));
 }
 
 // Effects
 bool PersonalizationDBusProxy::loadEffect(const QString &name)
 {
+    if (!m_WMInter) {
+        return false;
+    }
     return QDBusPendingReply<bool>(m_EffectsInter->asyncCall(QStringLiteral("loadEffect"), QVariant::fromValue(name)));
 }
 
 void PersonalizationDBusProxy::unloadEffect(const QString &name)
 {
+    if (!m_EffectsInter) {
+        return;
+    }
     m_EffectsInter->asyncCall(QStringLiteral("unloadEffect"), QVariant::fromValue(name));
 }
 
 bool PersonalizationDBusProxy::isEffectLoaded(const QString &name)
 {
+    if (!m_WMInter) {
+        return false;
+    }
     return QDBusPendingReply<bool>(m_EffectsInter->asyncCall(QStringLiteral("isEffectLoaded"), QVariant::fromValue(name)));
 }
 
 bool PersonalizationDBusProxy::isEffectLoaded(const QString &name, QObject *receiver, const char *member)
 {
+    if (!m_WMInter) {
+        return false;
+    }
     QList<QVariant> args;
     args << QVariant::fromValue(name);
     return m_EffectsInter->callWithCallback(QStringLiteral("isEffectLoaded"), args, receiver, member);
 }
 
+QString PersonalizationDBusProxy::activeColors()
+{
+    return QDBusPendingReply<QString>(m_AppearanceInter->asyncCall(QStringLiteral("GetActiveColors")));
+}
+
+void PersonalizationDBusProxy::setActiveColors(const QString &activeColors)
+{
+    m_AppearanceInter->asyncCall(QStringLiteral("SetActiveColors"), QVariant::fromValue(activeColors));
+}
+
 void PersonalizationDBusProxy::onPropertiesChanged(const QDBusMessage &message)
 {
     QVariantMap changedProps = qdbus_cast<QVariantMap>(message.arguments().at(1).value<QDBusArgument>());
