@@ -43,6 +43,22 @@ TreeLandWorker::TreeLandWorker(PersonalizationModel *model, QObject *parent)
 
 #ifdef Enable_Treeland
 
+void TreeLandWorker::setWallpaperForMonitor(const QString &screen, const QString &url, bool isDark, PersonalizationExport::WallpaperSetOption option)
+{
+    if (checkWallpaperLockStatus()) {
+        return;
+    }
+
+    if (option == PersonalizationExport::Option_Desktop) {
+        setBackgroundForMonitor(screen, url, isDark);
+    } else if (option == PersonalizationExport::Option_Lock) {
+        setLockBackForMonitor(screen, url, isDark);
+    } else if (option == PersonalizationExport::Option_All) {
+        setBackgroundForMonitor(screen, url, isDark);
+        setLockBackForMonitor(screen, url, isDark);
+    }
+}
+
 void TreeLandWorker::setBackgroundForMonitor(const QString &monitorName, const QString &url, bool isDark)
 {
     setWallpaper(monitorName, url, isDark, PersonalizationWallpaperContext::options_background);
@@ -81,10 +97,12 @@ void TreeLandWorker::setDefault(const QJsonObject &value)
     PersonalizationWorker::setDefault(value);
 }
 
-void TreeLandWorker::setAppearanceTheme(const QString &id)
+void TreeLandWorker::setAppearanceTheme(const QString &id, bool keepAuto)
 {
     qCDebug(DdcPersonnalizationTreelandWorker) << "setAppearanceTheme:" << id;
-    PersonalizationWorker::setAppearanceTheme(id);
+    if (!keepAuto) {
+        PersonalizationWorker::setAppearanceTheme(id);
+    }
     if (id == ".light" && m_appearanceTheme != PersonalizationAppearanceContext::theme_type::theme_type_light) {
         m_appearanceTheme = PersonalizationAppearanceContext::theme_type::theme_type_light;
         m_appearanceContext->set_window_theme_type(PersonalizationAppearanceContext::theme_type::theme_type_light);
@@ -153,15 +171,15 @@ void TreeLandWorker::setActiveColor(const QString &hexColor)
     m_appearanceContext->set_active_color(hexColor);
 }
 
-void TreeLandWorker::setFontSize(const int value) 
+void TreeLandWorker::setFontSize(const int pixelSize) 
 {
-    qCDebug(DdcPersonnalizationTreelandWorker) << "setFontSize:" << value;
-    if (m_fontSize == value) {
+    qCDebug(DdcPersonnalizationTreelandWorker) << "setFontSize:" << pixelSize;
+    if (m_fontSize == pixelSize) {
         return;
     }
-    m_fontSize = value;
-    PersonalizationWorker::setFontSize(value);
-    m_fontContext->set_font_size(pxToPt(value) * 10);
+    m_fontSize = pixelSize;
+    PersonalizationWorker::setFontSize(pixelSize);
+    m_fontContext->set_font_size(pxToPt(pixelSize) * 10);
 }
 
 void TreeLandWorker::setTitleBarHeight(int value)
@@ -273,6 +291,11 @@ void TreeLandWorker::wallpaperMetaDataChanged(const QString &data)
 void TreeLandWorker::setWallpaper(const QString &monitorName, const QString &url, bool isDark, uint32_t option)
 {
     qCDebug(DdcPersonnalizationTreelandWorker) << "setWallpaper:" << monitorName << "url:" << url << "isDark:" << isDark << "option:" << option;
+
+    if (checkWallpaperLockStatus()) {
+        return;
+    }
+
     if (!m_wallpaperContext)
         return;
 
@@ -446,7 +469,7 @@ void TreeLandWorker::doSetByType(const QString &type, const QString &value)
     } else if (type == TYPEFONTSIZE) {
         double pointSize = value.toDouble();
         if (pointSize > 0) {
-            setFontSize(pointSize);
+            setFontSize(ptToPx(pointSize));
         }
     } else if (type == TYPEACTIVECOLOR) {
         setActiveColor(value);
@@ -553,12 +576,13 @@ void PersonalizationAppearanceContext::treeland_personalization_appearance_conte
 
 void PersonalizationAppearanceContext::treeland_personalization_appearance_context_v1_window_opacity(uint32_t opacity)
 {
-    m_model->setOpacity(opacity);
+    // Using the value of the appearance module, this is an invalid value
+    // m_model->setOpacity(opacity / 100.0);
 }
 
 void PersonalizationAppearanceContext::treeland_personalization_appearance_context_v1_window_theme_type(uint32_t)
 {
-
+    // Using the value of the appearance module, this is an invalid value
 }
 
 void PersonalizationAppearanceContext::treeland_personalization_appearance_context_v1_window_titlebar_height(uint32_t height)
