@@ -16,6 +16,7 @@
 #include <QDateTime>
 #include <QFutureWatcher>
 #include <QtConcurrent/qtconcurrentrun.h>
+#include <QClipboard>
 
 #include <qregularexpression.h>
 #include <qtimezone.h>
@@ -23,6 +24,9 @@
 
 DCORE_USE_NAMESPACE
 
+const QString USER_EXPERIENCE_SERVICE = "com.deepin.userexperience.Daemon";
+
+
 namespace DCC_NAMESPACE{
 
 SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
@@ -32,8 +36,15 @@ SystemInfoWork::SystemInfoWork(SystemInfoModel *model, QObject *parent)
     , m_process(nullptr)
     , m_content("")
     , m_title("")
+    , m_dBusUeProgram(nullptr)
 {
     qRegisterMetaType<ActiveState>("ActiveState");
+    m_dBusUeProgram = new QDBusInterface(
+        "org.deepin.dde.EventLog1",
+        "/org/deepin/dde/EventLog1",
+        "org.deepin.dde.EventLog1",
+        QDBusConnection::sessionBus(), this);
+
     connect(m_systemInfDBusProxy,
             &SystemInfoDBusProxy::StaticHostnameChanged,
             m_model,
@@ -85,14 +96,20 @@ void SystemInfoWork::activate()
     QString version;
     if (DSysInfo::uosType() == DSysInfo::UosServer || DSysInfo::uosEditionType() == DSysInfo::UosEuler) {
         version = QString("%1%2").arg(DSysInfo::minorVersion(), DSysInfo::uosEditionName());
+        m_model->setVersion(version);
     } else if (DSysInfo::isDeepin()) {
-        version = QString("%1 (%2)").arg(DSysInfo::uosEditionName(), DSysInfo::minorVersion());
+        QDBusConnection::systemBus().connect("com.deepin.license",
+                                     "/com/deepin/license/Info",
+                                     "com.deepin.license.Info",
+                                     "LicenseStateChange",
+                                     this, SLOT(onLicenseAuthorizationProperty()));
+
+        onLicenseAuthorizationProperty();
     } else {
         version = QString("%1 %2").arg(DSysInfo::productVersion(), DSysInfo::productTypeString());
+        m_model->setVersion(version);
     }
 
-
-    m_model->setVersion(version);
     m_model->setType(QSysInfo::WordSize);
     m_model->setKernel(QSysInfo::kernelVersion());
     m_model->setProcessor(DSysInfo::cpuModelName());
@@ -113,8 +130,9 @@ void SystemInfoWork::activate()
     m_model->setPrivacyPolicy(text);
 
     // 用户体验计划内容
-    m_model->setJoinUeProgram(m_systemInfDBusProxy->IsEnabled());
-    http = IS_COMMUNITY_SYSTEM ? tr("https://www.deepin.org/en/agreement/privacy/") : tr("https://www.uniontech.com/agreement/privacy-en");
+    m_model->setJoinUeProgram(isUeProgramEnabled());
+
+    http = IS_COMMUNITY_SYSTEM ? tr("https://www.deepin.org/en/agreement/privacy/") : tr("https://www.uniontech.com/agreement/experience-en");
     if (IS_COMMUNITY_SYSTEM) {
         text = tr("<p>Joining User Experience Program means that you grant and authorize us to collect and use the information of your device, system and applications. "
                   "If you refuse our collection and use of the aforementioned information, do not join User Experience Program. "
@@ -122,8 +140,7 @@ void SystemInfoWork::activate()
                .arg(http);
     } else {
         text = tr("<p>Joining User Experience Program means that you grant and authorize us to collect and use the information of your device, system and applications. "
-                  "If you refuse our collection and use of the aforementioned information, do not join User Experience Program. "
-                  "To know more about the management of your data, please refer to UnionTech OS Privacy Policy (<a href=\"%1\"> %1</a>).</p>")
+                  "If you refuse our collection and use of the aforementioned information, please do not join it. For the details of User Experience Program, please visit <a href=\"%1\"> %1</a>.</p>")
                .arg(http);
     }
     m_model->setUserExperienceProgramText(text);
@@ -195,10 +212,19 @@ void SystemInfoWork::initUserLicenseData()
     }));
 }
 
+// Removed the placeholder comment
+void SystemInfoWork::copyTextToClipboard(const QString &text)
+{
+    QClipboard *clipboard = QGuiApplication::clipboard();
+    if (clipboard) {
+        clipboard->setText(text);
+    }
+}
+
 void SystemInfoWork::initSystemCopyright()
 {
     const QSettings settings("/etc/deepin-installer.conf", QSettings::IniFormat);
-    QString oem_copyright = settings.value("system_info_vendor_name").toString().toLatin1();
+    QString oem_copyright = settings.value("system_info_vendor_name").toString().toUtf8();
     if (oem_copyright.isEmpty()) {
         if (DSysInfo::productType() != DSysInfo::ProductType::Uos)
             oem_copyright = QCoreApplication::translate("LogoModule", "Copyright© 2011-%1 Deepin Community")
@@ -279,13 +305,13 @@ QString SystemInfoWork::getSystemInstallDate(int shortDateFormat, QString timezo
         }
     }
     qDebug() << "Utc offset:" << offset;
-   // QString aa = "2024-09-05 22:40:25 UTC+08";
-    QDateTime dateTime = QDateTime::fromString(inputTime, "yyyy-MM-dd hh:mm:ss 'UTC'zzz");
+    QDateTime dateTime = QDateTime::fromString(inputTime, "yyyy-MM-dd hh:mm:ss 'UTC'tt");
 
     dateTime.setOffsetFromUtc(offset * 3600);
     if (dateTime.isValid() && shortDateFormat >= 0 && shortDateFormat <= 10) {
         // 将时间转换到目标时区
         QTimeZone targetTimeZone(timezone.toLocal8Bit());
+        qDebug() << "targetTimeZone :" << targetTimeZone.isValid() << timezone;
         QDateTime convertedDateTime = dateTime.toTimeZone(targetTimeZone);
         qDebug() << "Converted DateTime:" << convertedDateTime;
         return convertedDateTime.toString(fotmatShortDate[shortDateFormat]);
@@ -327,38 +353,57 @@ static QString getUserExpContent()
 
 void SystemInfoWork::setUeProgram(bool enabled)
 {
-    QString current_date = QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm::ss.zzz");
-    if (enabled) {
-        qInfo("suser opened experience project switch.");
+    QDateTime current_date_time = QDateTime::currentDateTime();
+    QString current_date = current_date_time.toString("yyyy-MM-dd hh:mm::ss.zzz");
+    if (enabled && (isUeProgramEnabled() != enabled)) {
+        Q_EMIT requestUeProgram(true);
+        qInfo() << "Suser opened experience project switch";
         // 打开license-dialog必要的三个参数:标题、license文件路径、checkBtn的Text
         QString allowContent(tr("Agree and Join User Experience Program"));
 
-        // license路径
+               // license路径
         m_content = getUserExpContent();
 
         m_process = new QProcess(this);
 
         auto pathType = "-c";
-        if (!SYSTEM_LOCAL_LIST.contains(QLocale::system().name()))
+        const QStringList &sl {
+            "zh_CN",
+            "zh_HK",
+            "zh_TW",
+            "ug_CN", // 维语
+            "bo_CN" // 藏语
+        };
+        if (!sl.contains(QLocale::system().name()))
             pathType = "-e";
         m_process->start("dde-license-dialog",
-                                      QStringList() << "-t" << m_title << pathType << m_content << "-a" << allowContent);
+                         QStringList() << "-t" << m_title << pathType << m_content << "-a" << allowContent);
         qDebug()<<" Deliver content QStringList() = "<<"dde-license-dialog"
                                                      << "-t" << m_title << pathType << m_content << "-a" << allowContent;
         connect(m_process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [=](int result) {
             if (96 == result) {
-                m_systemInfDBusProxy->Enable(enabled);
-                m_model->setJoinUeProgram(enabled);
+                if (!m_model->joinUeProgram()) {
+                    m_model->setJoinUeProgram(enabled);
+                    qInfo() << QString("On %1, users open the switch to join the user experience program!").arg(current_date);
+                }
+                setUeProgramEnabled(enabled);
             } else {
-                m_model->setJoinUeProgram(!enabled);
+                m_model->setJoinUeProgram(isUeProgramEnabled());
                 qInfo() << QString("On %1, users cancel the switch to join the user experience program!").arg(current_date);
             }
+            Q_EMIT requestUeProgram(false);
             m_process->deleteLater();
             m_process = nullptr;
         });
     } else {
-        m_systemInfDBusProxy->Enable(enabled);
-        m_model->setJoinUeProgram(enabled);
+        if (isUeProgramEnabled() != enabled) {
+            setUeProgramEnabled(enabled);
+            qDebug() << QString("On %1, users close the switch to join the user experience program!").arg(current_date);
+        }
+        if (m_model->joinUeProgram() != enabled) {
+            m_model->setJoinUeProgram(enabled);
+            qDebug() << QString("On %1, users cancel the switch to join the user experience program!").arg(current_date);
+        }
     }
 }
 
@@ -392,4 +437,68 @@ void SystemInfoWork::onShortDateFormatChanged(const int shortDateFormate)
     m_model->setSystemInstallationDate(getSystemInstallDate(m_systemInfDBusProxy->shortDateFormat(), m_systemInfDBusProxy->timezone()));
 }
 
+bool SystemInfoWork::isUeProgramEnabled()
+{
+    if (!m_dBusUeProgram || !m_dBusUeProgram->isValid())
+        return false;
+
+    if (m_dBusUeProgram->service() == USER_EXPERIENCE_SERVICE) {
+        QDBusMessage reply = m_dBusUeProgram->call("IsEnabled");
+        QList<QVariant> outArgs = reply.arguments();
+        if (QDBusMessage::ReplyMessage == reply.type() && !outArgs.isEmpty()) {
+            return outArgs.first().toBool();
+        }
+    }
+
+    return m_dBusUeProgram->property("Enabled").toBool();
+}
+
+void SystemInfoWork::setUeProgramEnabled(bool enabled)
+{
+
+    if (!m_dBusUeProgram || !m_dBusUeProgram->isValid())
+        return;
+
+    if (m_dBusUeProgram->service() == USER_EXPERIENCE_SERVICE) {
+        m_dBusUeProgram->asyncCall("Enable", enabled);
+        return;
+    }
+
+    m_dBusUeProgram->asyncCall("Enable", enabled);
+}
+
+void SystemInfoWork::onLicenseAuthorizationProperty()
+{
+    // 从授权服务器获取授权类型
+    QString authorizationProperty = getLicenseAuthorizationPropertyString();
+    QString version = "";
+    if (authorizationProperty != "") {
+        version = QString("%1 (%2) (%3)").arg(DSysInfo::uosEditionName())
+                .arg(authorizationProperty)
+                .arg(DSysInfo::minorVersion());
+    } else {
+        version = QString("%1 (%2)").arg(DSysInfo::uosEditionName())
+                .arg(DSysInfo::minorVersion());
+    }
+
+    if (m_model) {
+        m_model->setVersion(version);
+    }
+}
+
+QString SystemInfoWork::getLicenseAuthorizationPropertyString()
+{
+    QDBusInterface licenseInfo("com.deepin.license",
+                               "/com/deepin/license/Info",
+                               "com.deepin.license.Info",
+                               QDBusConnection::systemBus());
+
+    if (!licenseInfo.isValid()) {
+        qWarning() << "Servie: com.deepin.license error: " << licenseInfo.lastError().name();
+        return "";
+    }
+
+    return licenseInfo.property("AuthorizationPropertyString").toString();
+}
+
 }
