@@ -6,6 +6,7 @@
 
 #include <qprocess.h>
 
+#include <QDBusInterface>
 #include <QDBusMessage>
 #include <QObject>
 
@@ -37,15 +38,22 @@ public:
     Q_INVOKABLE void setUeProgram(bool enabled);
     Q_INVOKABLE void showActivatorDialog();
     Q_INVOKABLE void showDetail();
+    Q_INVOKABLE void copyTextToClipboard(const QString &text); // Add new invokable method
+
+    bool isUeProgramEnabled();
+    void setUeProgramEnabled(bool enabled);
+    QString getLicenseAuthorizationPropertyString();
 
 Q_SIGNALS:
     void requestSetAutoHideDCC(const bool visible) const;
+    void requestUeProgram(bool visible) const;
 
 public Q_SLOTS:
     void onSetHostname(const QString &hostname);
     void onSetHostnameFinish();
     void onTimezoneChanged(const QString timezone);
     void onShortDateFormatChanged(const int shortDateFormate);
+    void onLicenseAuthorizationProperty();
 
 private:
     void getLicenseState();
@@ -56,6 +64,8 @@ private:
     QProcess *m_process = nullptr;
     QString m_content;
     QString m_title;
+    QDBusInterface *m_dBusUeProgram; // for user experience program
+
 };
 
 }
